==> hoogle-5.0.13-24-i686.pkg.tar.xz: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hoogle
version: 5.0.13
id: hoogle-5.0.13-FJ0qpJSpPrn1MTMwqq3Xjf
key: hoogle-5.0.13-FJ0qpJSpPrn1MTMwqq3Xjf
license: BSD3
copyright: Neil Mitchell 2004-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: http://hoogle.haskell.org/
synopsis: Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Hoogle
hidden-modules: Paths_hoogle Action.CmdLine Action.Generate
                Action.Search Action.Server Action.Test Input.Cabal Input.Download
                Input.Haddock Input.Item Input.Reorder Input.Set Input.Settings
                Output.Items Output.Names Output.Tags Output.Types Query
                General.Conduit General.IString General.Log General.Store
                General.Str General.Template General.Timing General.Util
                General.Web
abi: 5d8e9cb82fe760bf27ba209801ee8624
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hoogle-5.0.13
library-dirs: /usr/lib/ghc-8.2.1/site-local/hoogle-5.0.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hoogle
hs-libraries: HShoogle-5.0.13-FJ0qpJSpPrn1MTMwqq3Xjf
include-dirs: /usr/lib/ghc-8.2.1/site-local/hoogle-5.0.13/include
includes:
    include.h
depends:
    QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y base-4.10.0.0 binary-0.8.5.1
    bytestring-0.10.8.2 cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    conduit-extra-1.1.17-9f1YthVxnWoJohELB9cKUK
    connection-0.2.8-DV3SXnPmo3U13Xbkb1AWD4 containers-0.5.10.2
    deepseq-1.4.3.0 directory-1.3.0.2 extra-1.6-21C3t0YQFbADxH75E4GqjW
    filepath-1.4.1.2 old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM
    haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR
    http-conduit-2.2.3.2-LE3NbOXpVMUHyxyPrbRXgs
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    js-flot-0.8.3-JDUwO3yTt2e3BCiAqqIjur
    js-jquery-3.2.1-GyZ9FJonY6dAAMhwJ2fANo
    mmap-0.5.9-EWtfmxbT8jF8qY63lOubUM process-1.6.1.0
    process-extras-0.7.2-7zh8emYkG8r47ou2ansqVq
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    tar-0.5.0.3-INtpRXtFzzEKq72z4RSP9M template-haskell-2.12.0.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    transformers-0.5.2.0 uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs
    warp-3.2.13-CqJVCwIbQDLAJvEXSHcVnZ
    warp-tls-3.2.4-Lt5IC4f26tl5ZlmMwiq08
    zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
abi-depends: QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX=31c7a57798b8306ee987164ad717d7a8
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf=7dc5ecfdbaee81800275945c72ee928b
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=52e9aaa2724a9edb2ade5ee067f8810a
             conduit-extra-1.1.17-9f1YthVxnWoJohELB9cKUK=56fd5c6de95125ae43c66f7b1cc14a76
             connection-0.2.8-DV3SXnPmo3U13Xbkb1AWD4=00d5e04b887a765cbea71554bd2d160c
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             extra-1.6-21C3t0YQFbADxH75E4GqjW=90b9a896fb2ef8ae52715c35e2c32c8c
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=bb3d8fbe7de4d3cc9ed854226de736b7
             haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR=ac9b27fa2ca0fe7a0941d00fbc5a411d
             http-conduit-2.2.3.2-LE3NbOXpVMUHyxyPrbRXgs=90b62e5282785eee8954bb638b079701
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             js-flot-0.8.3-JDUwO3yTt2e3BCiAqqIjur=0cdac5fc80a85c6317508d2070b6fb1c
             js-jquery-3.2.1-GyZ9FJonY6dAAMhwJ2fANo=4d58de2c3802cae449ee216ff9fea033
             mmap-0.5.9-EWtfmxbT8jF8qY63lOubUM=559239d13beb664e048711605c559cd4
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             process-extras-0.7.2-7zh8emYkG8r47ou2ansqVq=86846902f2148588960b894131ff2ade
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             tar-0.5.0.3-INtpRXtFzzEKq72z4RSP9M=8e406c0774fd4cbc65b7b5ac4ea9d53b
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ=3300bc881e9fb75483828891b71f16f8
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=ff7de6695cfb4cde5628a04fa6d123e7
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=b2b1b36770028b18814f7469d1a17fa5
             wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs=980351279c4942632d0628edb229e7b9
             warp-3.2.13-CqJVCwIbQDLAJvEXSHcVnZ=55b121d359036e442f9647dd16cddbb6
             warp-tls-3.2.4-Lt5IC4f26tl5ZlmMwiq08=fb2a9489123904acddd598a034e4e133
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=c1d55c3251ed960ccd96b402a1d90259
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
haddock-interfaces: /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html: /usr/share/doc/hoogle/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hoogle-5.0.13-25-i686.pkg.tar.xz: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hoogle
version: 5.0.13
id: hoogle-5.0.13-CXijSUrdHwm4CS8cLmlU8R
key: hoogle-5.0.13-CXijSUrdHwm4CS8cLmlU8R
license: BSD3
copyright: Neil Mitchell 2004-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: http://hoogle.haskell.org/
synopsis: Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    Hoogle
hidden-modules: Paths_hoogle Action.CmdLine Action.Generate
                Action.Search Action.Server Action.Test Input.Cabal Input.Download
                Input.Haddock Input.Item Input.Reorder Input.Set Input.Settings
                Output.Items Output.Names Output.Tags Output.Types Query
                General.Conduit General.IString General.Log General.Store
                General.Str General.Template General.Timing General.Util
                General.Web
abi: 45fa31c0cf830b54ac98a4398467e5bc
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hoogle-5.0.13
library-dirs: /usr/lib/ghc-8.2.1/site-local/hoogle-5.0.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hoogle
hs-libraries: HShoogle-5.0.13-CXijSUrdHwm4CS8cLmlU8R
include-dirs: /usr/lib/ghc-8.2.1/site-local/hoogle-5.0.13/include
includes:
    include.h
depends:
    QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y base-4.10.0.0 binary-0.8.5.1
    bytestring-0.10.8.2 cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    conduit-extra-1.1.17-9f1YthVxnWoJohELB9cKUK
    connection-0.2.8-DMHF7pH68f1CIg10bEvXf6 containers-0.5.10.2
    deepseq-1.4.3.0 directory-1.3.0.2 extra-1.6-21C3t0YQFbADxH75E4GqjW
    filepath-1.4.1.2 old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM
    haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR
    http-conduit-2.2.3.2-A5AFsDzznqQIMc9xJ3F5i8
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    js-flot-0.8.3-JDUwO3yTt2e3BCiAqqIjur
    js-jquery-3.2.1-GyZ9FJonY6dAAMhwJ2fANo
    mmap-0.5.9-EWtfmxbT8jF8qY63lOubUM process-1.6.1.0
    process-extras-0.7.2-7zh8emYkG8r47ou2ansqVq
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    tar-0.5.0.3-INtpRXtFzzEKq72z4RSP9M template-haskell-2.12.0.0
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz time-1.8.0.2
    transformers-0.5.2.0 uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ
    utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs
    warp-3.2.13-CqJVCwIbQDLAJvEXSHcVnZ
    warp-tls-3.2.4-7KX2nmBImXvGzXfyDwHslV
    zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
    network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx
abi-depends: QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX=31c7a57798b8306ee987164ad717d7a8
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf=7dc5ecfdbaee81800275945c72ee928b
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=52e9aaa2724a9edb2ade5ee067f8810a
             conduit-extra-1.1.17-9f1YthVxnWoJohELB9cKUK=56fd5c6de95125ae43c66f7b1cc14a76
             connection-0.2.8-DMHF7pH68f1CIg10bEvXf6=ad775625a6ea9be6af13869208f6e3c5
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             extra-1.6-21C3t0YQFbADxH75E4GqjW=90b9a896fb2ef8ae52715c35e2c32c8c
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             old-locale-1.0.0.7-1sqf81TERjR1yVX7sI2OtM=bb3d8fbe7de4d3cc9ed854226de736b7
             haskell-src-exts-1.19.1-1RWeGLmCUODCaSeMHs0BKR=ac9b27fa2ca0fe7a0941d00fbc5a411d
             http-conduit-2.2.3.2-A5AFsDzznqQIMc9xJ3F5i8=51d4c6f99c74e019b4efb116f3d966a4
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=dac2e6d9eb3caedd3c76c9c39d0f2e0c
             js-flot-0.8.3-JDUwO3yTt2e3BCiAqqIjur=0cdac5fc80a85c6317508d2070b6fb1c
             js-jquery-3.2.1-GyZ9FJonY6dAAMhwJ2fANo=4d58de2c3802cae449ee216ff9fea033
             mmap-0.5.9-EWtfmxbT8jF8qY63lOubUM=559239d13beb664e048711605c559cd4
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             process-extras-0.7.2-7zh8emYkG8r47ou2ansqVq=86846902f2148588960b894131ff2ade
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             tar-0.5.0.3-INtpRXtFzzEKq72z4RSP9M=8e406c0774fd4cbc65b7b5ac4ea9d53b
             template-haskell-2.12.0.0=84fec1eab31df12231c00a687a39fdc3
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             time-1.8.0.2=96b65c0ad01f633ba36ea5ef13a79f41
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ=3300bc881e9fb75483828891b71f16f8
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=ff7de6695cfb4cde5628a04fa6d123e7
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=bde86a27d0899b74a82f3bf1fe9b817c
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=b2b1b36770028b18814f7469d1a17fa5
             wai-logger-2.3.0-9cV4zbM0jVb2n8dfPIJIxs=980351279c4942632d0628edb229e7b9
             warp-3.2.13-CqJVCwIbQDLAJvEXSHcVnZ=55b121d359036e442f9647dd16cddbb6
             warp-tls-3.2.4-7KX2nmBImXvGzXfyDwHslV=29411acb041eeb98725f524de4e91163
             zlib-0.6.1.2-6xNZGE39eOa1IjQdEzckzB=c1d55c3251ed960ccd96b402a1d90259
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
             network-2.6.3.2-8o5F7G3DMrLGgmHkPzZYJx=dc3f2353580d7555dd3bad96e9f5af9d
haddock-interfaces: /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html: /usr/share/doc/hoogle/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
